@@ -13,13 +13,7 @@ print("-"*20,"\n")
 app = typer.Typer()
 
 
-@app.callback(invoke_without_command=True)
-def main(name:str):
-        
-    if not fetch(name):
-        exit()
-    os.chdir(fetch(name))
-    os.system("code .")    
+
 
 @app.command()
 def dropall():
